@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-05-11 14:50:27
-@LastEditors: HuangJianYi
+@LastEditTime: 2021-06-21 15:41:48
+@LastEditors: WangQiang
 :description: 用户处理
 """
 from seven_cloudapp.handlers.top_base import *
@@ -131,7 +131,10 @@ class SyncPayOrderHandler(TopBaseHandler):
 
                     now_price_gear_config = {}
                     for price_config in price_gear_list:
-                        if (price_config.effective_date == '1900-01-01 00:00:00' or TimeHelper.format_time_to_datetime(price_config.effective_date) < TimeHelper.format_time_to_datetime(order["pay_time"])) and price_config.goods_id == str(order["num_iid"]) and price_config.sku_id == str(order["sku_id"]):
+                        if (price_config.effective_date == '1900-01-01 00:00:00' or TimeHelper.format_time_to_datetime(price_config.effective_date) < TimeHelper.format_time_to_datetime(order["pay_time"])) and price_config.goods_id == str(order["num_iid"]):
+                            #关联类型：1商品skuid关联2商品id关联
+                            if price_config.relation_type == 1 and price_config.sku_id != str(order["sku_id"]):
+                                continue
                             now_price_gear_config = price_config
                             continue
 
