@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-05-28 16:23:32
-@LastEditors: HuangJianYi
+@LastEditTime: 2021-06-21 15:44:59
+@LastEditors: WangQiang
 :Description: 潮玩盲盒基础路由
 """
 # 框架引用
@@ -95,6 +95,8 @@ def seven_cloudapp_ppmt_route():
         (r"/server/user_detail", user_s.UserDetailHandler),
         (r"/server/integral", user_s.SurplusIntegralHandler),
         (r"/server/lottery_value_log_list", user_s.LotteryValueLogHandler),
+        # 2.1优化
+        (r"/server/checking_price_gear", machine_s.CheckingPriceGearHandler),  #验证价格档位
 
         # 客户端接口
         (r"/client/login", user.LoginHandler),
